#example 1, between indirect effect (2 paths)
require(MASS) #load required package
a=.455 #assign estimated values to parameters
b=.656
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b) #put estimates into a vector
#create 2x2 acov matrix from tech3 output in Mplus
acov <- matrix(c(
0.17810755E-01, 0.38238370E-02,
0.38238370E-02, 0.22770649E-01),2,2)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
ieb <- mcmc[,1]*mcmc[,2] #define indirect effect
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(ieb,low) #find lower confidence limit
UL=quantile(ieb,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b,LL,UL)) #print the output
#make a histogram
hist(ieb,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect')

#example 1, within indirect effect (2 paths)
require(MASS) #load required package
a=.375 #assign estimated values to parameters
b=.362
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b) #put estimates into a vector
#create 2x2 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.16491521E-02, -0.18865290E-03,
-0.18865290E-03,  0.21896878E-01),2,2)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
iew <- mcmc[,1]*mcmc[,2] #define indirect effect
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(iew,low) #find lower confidence limit
UL=quantile(iew,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b,LL,UL)) #print the output
#make a histogram
hist(iew,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect')

#example 1, difference of B and W indirect effects
require(MASS) #load required package
a=.455 #assign estimated values to parameters
b=.656
c=.375
d=.362
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b,c,d) #put estimates into a vector
#create 4x4 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.17810755E-01,  0.38238370E-02, -0.30266999E-02, -0.89393417E-04,
 0.38238370E-02,  0.22770649E-01,  0.10262729E-03,  0.68648195E-03,
-0.30266999E-02,  0.10262729E-03,  0.16491521E-02, -0.18865290E-03,
-0.89393417E-04,  0.68648195E-03, -0.18865290E-03,  0.21896878E-01
),4,4)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
#define indirect effect difference
iediff <- mcmc[,1]*mcmc[,2]-mcmc[,3]*mcmc[,4]
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(iediff,low) #find lower confidence limit
UL=quantile(iediff,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b-c*d,LL,UL)) #print the output
#make a histogram
hist(iediff,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect Difference')

#example 1, between indirect effect (3 paths)
require(MASS) #load required package
a=.455 #assign estimated values to parameters
b=.656
c=.602
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b,c) #put estimates into a vector
#create 3x3 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.17810755E-01,  0.38238370E-02, -0.85890777E-02,
 0.38238370E-02,  0.22770649E-01, -0.21358784E-01,
-0.85890777E-02, -0.21358784E-01,  0.66926164E-01),3,3)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
ieb <- mcmc[,1]*mcmc[,2]*mcmc[,3] #define indirect effect
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(ieb,low) #find lower confidence limit
UL=quantile(ieb,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b*c,LL,UL)) #print the output
#make a histogram
hist(ieb,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect')

#example 2, between indirect effect (2 paths)
require(MASS) #load required package
a=.357 #assign estimated values to parameters
b=.295
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b) #put estimates into a vector
#create 2x2 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.188400E-02, -0.106188E-03,
-0.106188E-03,  0.100600E-01),2,2)
#generate MVN parameter distribution 
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
ieb <- mcmc[,1]*mcmc[,2] #define indirect effect
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(ieb,low) #find lower confidence limit
UL=quantile(ieb,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b,LL,UL)) #print the output
#make a histogram
hist(ieb,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect')

#example 2, between indirect effect (3 paths)
require(MASS) #load required package
a=.357 #assign estimated values to parameters
b=.295
c=.185
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b,c) #put estimates into a vector
#create 3x3 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.188400E-02, -0.106188E-03, -0.447846E-04,
-0.106188E-03,  0.100600E-01, -0.418114E-03,
-0.447846E-04, -0.418114E-03,  0.310931E-02),3,3)
#generate MVN parameter distribution 
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
ieb <- mcmc[,1]*mcmc[,2]*mcmc[,3] #define indirect effect
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(ieb,low) #find lower confidence limit
UL=quantile(ieb,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b*c,LL,UL)) #print the output
#make a histogram
hist(ieb,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect')

#example 2, difference of B indirect effects
require(MASS) #load required package
a=.455 #assign estimated values to parameters
b=.656
c=.602
d=.357
e=.295
f=.185
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b,c,d,e,f) #put estimates into a vector
#create 6x6 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.178107E-01,  0.382340E-02, -0.858833E-02, 0, 0, 0,
 0.382340E-02,  0.227697E-01, -0.213564E-01, 0, 0, 0,
-0.858833E-02, -0.213564E-01,  0.669208E-01, 0, 0, 0,
 0, 0, 0,  0.188400E-02, -0.106188E-03, -0.447846E-04,
 0, 0, 0, -0.106188E-03,  0.100600E-01, -0.418114E-03,
 0, 0, 0, -0.447846E-04, -0.418114E-03,  0.310931E-02),6,6)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
#define indirect effect difference
iediff <- mcmc[,1]*mcmc[,2]*mcmc[,3]-mcmc[,4]*mcmc[,5]*mcmc[,6]
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(iediff,low) #find lower confidence limit
UL=quantile(iediff,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b*c-d*e*f,LL,UL)) #print the output
#make a histogram
hist(iediff,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect Difference')

#example 2, difference of unclustered and W indirect effects
require(MASS) #load required package
a=.375 #assign estimated values to parameters
b=.362
c=.357
d=.295
rep=10000000 #CI to be based on ten million reps
conf=95      #95% CI
pest <- c(a,b,c,d) #put estimates into a vector
#create 4x4 acov matrix from tech3 output in Mplus
acov <- matrix(c(
 0.16491521E-02, -0.18865290E-03, 0, 0,
-0.18865290E-03,  0.21896878E-01, 0, 0,
 0, 0,  0.188400E-02, -0.106188E-03,
 0, 0, -0.106188E-03,  0.100600E-01),4,4)
#generate MVN parameter distribution
mcmc <- mvrnorm(rep,pest,acov,empirical=FALSE)
#define indirect effect difference
iediff <- mcmc[,1]*mcmc[,2]-mcmc[,3]*mcmc[,4]
low=(1-conf/100)/2
upp=((1-conf/100)/2)+(conf/100)
LL=quantile(iediff,low) #find lower confidence limit
UL=quantile(iediff,upp) #find upper confidence limit
LL4=format(LL,digits=4) #round to 4 places
UL4=format(UL,digits=4) #round to 4 places
print(c(a*b-c*d,LL,UL)) #print the output
#make a histogram
hist(iediff,breaks='FD',col='skyblue',
  xlab=paste(conf,'% Confidence Interval ','LL',LL4,'  UL',UL4),
  main='Distribution of Indirect Effect Difference')

